window.Gleam.initSearch([{"doc":"eventsourcing_inmemory","title":"eventsourcing_inmemory","content":"&lt;h1 align=&quot;center&quot;&gt;eventsourcing_inmemory&lt;/h1&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  ✨ &lt;strong&gt;In-Memory Event Store Implementation for Eventsourcing&lt;/strong&gt; ✨\n&lt;/div&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://hex.pm/packages/eventsourcing_inmemory&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/hexpm/v/eventsourcing_inmemory&quot; alt=&quot;Package Version&quot; /&gt;\n  &lt;/a&gt;\n  &lt;a href=&quot;https://hexdocs.pm/eventsourcing_inmemory&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/badge/hex-docs-ffaff3&quot; alt=&quot;Hex Docs&quot; /&gt;\n  &lt;/a&gt;\n&lt;/div&gt;\n\n---\n\n## Introduction\n\n`eventsourcing_inmemory` provides an in-memory event store implementation for the [eventsourcing](https://github.com/renatillas/eventsourcing) library.\nIt&#39;s designed for development, testing, and small-scale applications where persistence isn&#39;t required.\n\n## Features\n\n- **In-Memory Storage**: Fast, non-persistent event storage\n- **Snapshot Support**: Built-in snapshot management for optimizing aggregate rebuilding\n- **Concurrent Access**: Safe concurrent access to events and snapshots\n- **Error Handling**: Comprehensive error handling with timeouts and process monitoring\n- **Zero Configuration**: Ready to use with minimal setup\n\n## Installation\n\nAdd to your Gleam project:\n\n```sh\ngleam add eventsourcing_inmemory\n```\n\n## Usage\n\n### Basic Setup\n\n```Gleam\nimport eventsourcing\nimport eventsourcing_inmemory\n\npub fn main() {\n  // Create a new in-memory event store\n  let store = eventsourcing_inmemory.new()\n  \n  // Create an event sourcing instance with the store\n  let event_sourcing = eventsourcing.new(\n    event_store: store,\n    queries: [],\n    handle: your_command_handler,\n    apply: your_event_applier,\n    empty_state: your_empty_state,\n  )\n  // Enable snapshots (optional)\n  |&gt; with_snapshots(\n    event_sourcing,\n    eventsourcing.SnapshotConfig(100), // Snapshot every 100 events\n  )\n}\n```\n","url":"index.html"},{"doc":"eventsourcing_inmemory","title":"MemoryStore","content":"pub opaque type MemoryStore(entity, command, event, error)\n\n\nSynonyms:\neventsourcing_inmemory.MemoryStore\neventsourcing_inmemory MemoryStore","url":"eventsourcing_inmemory.html#MemoryStore"},{"doc":"eventsourcing_inmemory","title":"new","content":"pub fn new() -&gt; EventStore(MemoryStore(a, b, c, d), a, b, c, d)\n Create a new memory store record.\nSynonyms:\neventsourcing_inmemory.new\neventsourcing_inmemory new","url":"eventsourcing_inmemory.html#new"},{"doc":"eventsourcing_inmemory","title":"eventsourcing_inmemory","content":"","url":"eventsourcing_inmemory.html"}]);